Handbook - Epithelial System Hypodermis
Description: WormAtlas: A database of behavioral and structural anatomy of Caenorhabditis elegans.
Keywords: Caenorhabditis, elegans, anatomy, hermaphrodite, worm, nematode

Home Handbooks Hermaphrodite Male Dauer Embryo Aging P. pacificus S. stercoralis Resources WormImage Slidable Worm WormWiring Hall Lab Anatomical Methods Glossary of Terms Movie Gallery Individual Neurons Neurons & Circuits Worm Literature Cell Identification Cell Lineages Cell List Sperm Gallery Digital Development DIC PharynxAtlas User Guides Abbreviations Color Codes Copyright and Use How to Cite Links WormBase WormBook CGC WormGUIDES CytoSHOW OpenWorm Nemanode CeNGEN C. elegans Natural Diversity Anatomy by DIC - by J. Yochem About Us Mission Statement Contact

EPITHELIAL SYSTEM HYPODERMIS (EPIDERMIS) Click pictures for new window with figure and legend, click again for high resolution image
1 Overview The epithelial system of C. elegans constitutes two general categories of cells: hypodermis and specialized epithelial cells. The hypodermis is made of the main body syncytium (hyp 7) and smaller hypodermal cells of the head and tail. The specialized epithelial cells secrete parts of the cuticle, direct the formation of specialized structures in the cuticle, and act as support cells (glia) for neuronal sensory receptors and as linker cells to attach the hypodermis to internal tissues while forming various holes in the cuticle. The hypodermis performs many functions during early development, including establishing the basic body plan, depositing basement membrane components, regulating cell fate specification of neighboring cells, guiding cell and axon migrations, and taking up apoptotic cell bodies by phagocytosis (Johnstone and Barry, 1996; Greenwald, 1997; Michaux et al., 2001). As the animal matures, the hypodermis is also important for storage of nutrients and deposition of stage-specific cuticles (molting), and it provides a barrier function for the pseudocoelomic cavity (Singh and Sulston, 1978; White, 1988; Kramer, 1997; Yochem et al., 1999; see also The Cuticle and Dauer Cuticle). Mutations in genes that affect the development and function of hypodermal cells result in defects in body morphogenesis, muscle development and cuticle structure and function. The mutants can produce arrested embryos or larvae and adults with dumpy (dpy) and roller (rol) phenotypes (Kramer, 1997; Fay et al., 1999; see also The Cuticle). Specialized epithelial cells, fall into three categories: (1) seam cells, which are also referred to as the lateral hypodermis (see Seam Cells); (2) interfacial epithelial cells, which are specialized linker cells located at the interface between hypodermis and another type of tissue (see Interfacial Cells); and (3) atypical epithelial cells, which include the XXX cells in the head and the tail spike cells, both of which have transient epithelial roles in embryonic development (see Atypical Cells). Epithelial cells of C. elegans are tightly held together by zonula adherens (formerly known as belt desmosomes) on their lateral borders, close to the apical surfaces. These junctions wrap around the epithelial cells and provide a seal and a mechanical link to the adjacent cells. They also segregate each cell membrane into two distinct regions: apical and basolateral surfaces (White, 1988; Michaux et al., 2001). In C. elegans, these junctions exhibit features of both adherens and tight junctions (Costa et al., 1998; Bossinger et al., 2001). The apical surfaces of the epithelial cells are bounded by the cuticle, and the basal surfaces are covered by the basal lamina. The hypodermis and seam cells form multinucleate syncytia that are generated by cell fusions during development (HypTABLE 1). These cell fusions are regulated by diverse signaling mechanisms (Witze and Rothman, 2002; Podbilewicz, 2006). HypTABLE 1: Most hypodermal cells are syncytial. ahyp 6 fuses with hyp 7 during mid-L3 stage (Yochem et al., 1998). bIn adult hermaphrodite, hyp 7 syncytium contains 139 nuclei. Twenty-three of these are fused embryonically (including hyp 13) and 116 are added postembryonically. Of the nuclei post-embryonically added to hyp 7, 98 derive from seam blast cell divisions (H, V and T lineages), 12 derive from P lineages (including hyp 12) and 6 derive from hyp 6. In the adult male, hyp 7 contains 144 nuclei (Shemer and Podbilewicz, 2000). chyp 8 - 11 are arranged similarly between the sexes until mid-L4 stage. In males, after mid-L4, hyp 8 fuses with hyp 11, followed by fusion with hyp 9 and finally with hyp 10 generating a syncytium with five nuclei (Nguyen et al., 1999). dVentral hypodermal cell or preanal hypodermis (P12.pa) (Sulston and Horvitz, 1977) eventually fuses with hyp 7 (Hedgecock and White, 1985). eSisters of the T cells (ABpl/rappppa) are located posterior to the anus (see cells 22 and 23 in HypFIG 2) and are present in males until very late L4 when they fuse with hyp 7 (Nguyen et al., 1999). In hermaphrodites, they fuse to generate the hyp 7 syncytium along with 21 other cells during elongation stage. fLeft and right cell groups. During embryonic and larval life they are unfused and act as stem cells. Late in L4 stage, H0-H15, post-embryonically derived seam cells on each side, undergo homotypic fusion to form the seam syncytia of adults (see Seam Cells).
2 Embryonic Development of the Hypodermis (also see Epidermal Morphogenesis in Wormbook) As in other triploblastic animals, the outer epithelium of C. elegans arises from the ectoderm. This tissue in C. elegans was originally named the hypodermis, although, in more recent literature it is sometimes referred to as the epidermis due to its ectodermal origin (Sulston and Horvitz, 1977; Wright, 1987). For practical purposes, we refer to it as hypodermis, because each hypodermal cell in C. elegans carries the three-letter acronym “hyp.” The hypodermis develops largely from three cell types: embryonically from the AB founder cell and postembryonically from the lateral seam cells and the ventral blast (P) cells. In the embryo, the hypodermis becomes a monolayer of 78 epithelial cells that secrete the cuticle (Sulston et al., 1983). The majority of the hypodermis is generated from the AB founder cell, which has an intrinsic ability to produce hypodermis and neurons. During the third round of AB division, the potential to generate hypodermis is nonequivalently restricted to four daughter cells of the AB granddaughter cells (the posterior two granddaughters of ABa and the anterior two granddaughters of ABp), whereas their sisters primarily become neuronal precursors (HypFIG 1). Of the four AB great-granddaughters, ABalp is later induced by the MS cell to generate the pharynx, whereas the others continue with their major hypodermal fate (Cowan and McIntosh, 1985; Gendreau et al., 1994). HypFIG 1: Embryonic and post-embryonic lineages. Although many of the hypodermal and seam cells arise embryonically, more are added during each larval stage (based on Sulston and Horvitz, 1977; Sulston et al., 1983). A. Embryonic lineage. The major precursor for hypodermal lineages is the AB founder cell, whose daughters have a left-right asymmetry (cf., the lineage patterns of ABarp and Abalp, a major hypodermal precursor and a pharyngeal precursor, respectively). The C founder cell yields other posterior and dorsal hypodermal cells. (Dotted lines) More than one division occurs until final hypodermal cells are born. B&C. Postembryonically, additional cells that fuse with hyp 7 come from 2 major lineages; seam-precursor divisions (B) and P-cell divisions (C). ADEso; anterior deirid socket cell. (Shading) Each molt at 20-22°C. Time at hatching is 0. (X) Programmed cell death; (dt) daughter. Most of the embryonic hypodermal cells are born around 210-240 minutes after first cleavage at 20-22°C and form a posterior dorsal sheet of cells that is organized in six rows (HypFIG 2). This hypodermal sheet eventually spreads to wrap around the embryo until the ventral edges meet and form adherens junctions to close the embryo in a continuous hypodermal layer. The larger 58 cells of the initial dorsal layer of cells are organized in two inner, two middle and two outer rows with 20, 20 and18 cells, respectively, at about 250 minutes after the first cleavage. The remaining, smaller 20 cells (hyp 1-5, three cells of hyp 6, hyp 8-11) at the anterior and posterior will later form the hypodermis of the anterior head and the tail. Between 290 and 340 minutes, the two inner rows of the epithelial sheet migrate towards each other and intercalate to make a single row of cells (HypFIG 2) (Podbilewicz and White, 1994; Williams-Masson et al., 1998; Chisholm and Hardin, 2005; Chin-Sang and Chisholm, 2000; Shemer and Podbilewicz, 2000; Simske and Hardin, 2001). Dorsal intercalation is essential for successful elongation of the embryo at later stages, although it is not required for ventral enclosure or dorsal cell fusions (Heid et al., 2001). The alignment of cells causes a slight lengthening of the dorsal hypodermis relative to the lateral and ventral sides that causes a slight ventral bend in the body. HypFIG 2: Dorsal intercalation of the hypodermis (Also see Movie 2 and Movie 5 in Epidermal Morphogenesis in Wormbook). A. 250 minutes after first cleavage (filleted view of spheroidal embryo). The hypodermis arises as a patch of cells on the posterior dorsal side of the embryo where the cells organize into six rows. The two inner rows later intercalate (gray arrows) to make the dorsal hypodermis, the middle rows are formed by the seam precursors flanking the dorsal hypodermal cells, and the outer rows contain ventral hyp and P cells. (dm) Dorsal midline; (a) anus;(e) excretory pore; (d) anterior deirid. B. DIC of an approximately 300-minute embryo (dorsal view). During the initial stages of intercalation, the cells become wedge shaped and their basolateral protrusions insert underneath the adherens junctions of their opposite side neighbors. These basal protrusions then plow through their opposing neighbors while the nuclei of the migrating cells trail behind the basal tips. White arrows point to directions of migration. Nuclei of some hyp 7 cells are labeled for comparison with A and C. (S): Left-side seam progenitors (only V1-V6 are labeled). Two intercalating columns are seen posterior to the double-headed arrow. C. At 340 minutes (dorsal plane). When the intercalation of dorsal cells is complete, the nuclei are positioned in a dorsolateral location near the border of the seam cells, and new adherens junctions are formed between neighboring cells. The cells have changed from a rounded to an oblong shape. Nuclei 16 and 17 (of hyp 7) are located at the ventral turn of the dorsal hyp. Anterior hyp cells are not shown. D. At 360 minutes (filleted view). Dorsal hypodermal cells have completed their intercalation that will be followed by ventral enclosure and cell fusions to generate the main body syncytium of hyp 7. Cells I-VI will also fuse to make hyp 6 syncytium. hyp 1-3 cells, one hyp 4 cell (located anterior to IV), and tail hypodermal cells are not shown here (HypFIG 11A). (dm) Dorsal midline. Cells are numbered according to Podbilewicz and White (1994) (cell 1 in these images corresponds to cell 6 in Sulston et al., 1983). As dorsal intercalation nears completion, ventral enclosure begins (HypFIG 3). The enclosure of the ventral surface of the embryo involves a three-step process that leads to wrapping of the embryo in an epithelial monolayer (HypFIG 4A&B). In the initial step, two pairs of “leading cells” from the dorsolateral side elongate toward the ventral midline by extending actin-rich filopodia between the neuronal precursor cells underneath them. As these cells meet at the midline, the anterior pair of the leading cells is the first to establish stable adherens junctions, and eventually they fuse after enclosure to form part of the hyp 6 syncytium. The posterior pair also fuses and forms part of the hyp 7 syncytium. As the leading cells move toward the midline, the second step is initiated by the hypodermal cells that are posterior to the leading cells (the ventral pocket cells). These cells become wedge shaped and elongate toward the midline to form a “ventral pocket” around the ventral midline. In the third step, this pocket is sealed, possibly by an actomyosin-dependent purse-string mechanism or by migration of its free edges (Williams-Masson et al., 1997; Simske and Hardin, 2001). If the proper organization of the substrate for migration of hypodermal cells does not occur during earlier stages of embryogenesis, ventral enclosure defects arise. One example of this is a failure in gastrulation cleft closure (George et al., 1998; Chin-Sang et al., 1999; Chin-Sang and Chisholm, 2000). HypFIG 3: Embryonic hypodermal morphogenesis and major morphogenetic movements at 20°C. The first cleavage is time 0 (based on Chin-Sang and Chisholm, 2000; Simske and Hardin, 2001; Chisholm and Hardin, 2005). A. Gastrulation, approximately 100-250 minutes (DIC image), lateral view. Around the 26-cell stage, a gastrulation cleft (arrowhead) is created on the ventral side of the embryo, through which the germline, gut, and mesodermal precursors will move into the embryo (curved arrow). B. Approximately 230-290 minutes (DIC image), ventral view. Gastrulation cleft closes by movement of ventral ectodermal (mostly neuroblasts) cells (arrows). C. Approximately 290-340 minutes; dorsal hypodermal intercalation (DIC image), dorsal view. Neighboring cells move in opposite directions during intercalation (arrows). D. Approximately 310-360 minutes; ventral hypodermal closure (DIC image), ventral view. Ventral pocket cells seal the pocket in the direction shown by arrows. E. Approximately 360-600 minutes; hypodermal cell fusions and elongation of the embryo. Epifluorescent images of transgenic animals expressing the ajm-1::GFP reporter in the hypodermis. This marker gene is expressed at the apical borders of all epithelia and is required for the integrity of epithelial junctions (Koeppen et al., 2001). (Top) Tadpole-stage embryo lateral view; (bottom) threefold embryo, lateral view. (H) head; (T) tail; (h6) hyp 6; (h7) hyp7. Anterior seam cells (H1 and H2 in tadpole stage and H2, V1 and V2 in threefold-stage embryo) are marked. Arrowheads point to anterior deirid. (Strain source: H. Yu and P. W. Sternberg.) HypFIG 4: Ventral enclosure and elongation of the hypodermis. (Based on Chin-Sang and Chisholm, 2000; Simske and Hardin, 2001. Also see Movie 1 in Epidermal Morphogenesis in Wormbook.) A&B. Ventral enclosure takes place between 310 and 360 minutes after first cell cleavage, at 20°C, and proceeds in three steps. A. Ventral views. B. Lateral views. In the first step, the anterior leading cells (white stars) extend actin-rich filopodia toward the ventral midline over a substrate of neuronal precursor cells (red circles). In the second step, the leading cells meet at the midline and form adherens junctions, whereas cells posterior to them become wedge shaped and extend toward midline, creating a ventral pocket (white arrow). In the last step, the ventral pocket closes, possibly through a purse-string type contraction mechanism (gray circular arrows). Simultaneously with ventral enclosure, the anterior hypodermal cells (hyp 4, hyp 5) migrate from where they are born toward the anterior part of the embryo (not shown) (Labouesse, 1997). As the embryo reaches the comma stage, before the dorsal cell fusions start, ventral and anterior areas are covered completely. Hypodermal cells that will become part of hyp 6 syncytium are marked by thin stripes, whereas those that will become part of hyp 7 syncytium on the ventral side are marked by textured coloring. Dorsal hypodermal cells of hyp 7 are shown in brown and seam cells in orange. Anterior hypodermal cells are not shown. Black arrowheads point to the excretory pore cell (middle image) or excretory pore (bottom images). C. Elongation takes place after the embryo is covered and sealed by hypodermis. Contraction of circumferential actin filaments, especially within the seam cells, causes elongation of the embryo, thus increasing its length approximately fourfold and decreasing its thickness about threefold (see top and bottom epifluorescent images in HypFIG 3E). After the ventral enclosure is completed, around 300-350 minutes after first cell cleavage at 20°C, the embryo begins to elongate along its anterior-posterior axis (Priess and Hirsh, 1986; Simske and Hardin, 2001; Chisholm and Hardin, 2005). Apical surfaces of the hypodermal cells are squeezed circumferentially, resulting in pressure on internal structures and elongation of the whole embryo. Elongation causes the circumference of the animal to decrease threefold and its length to increase about fourfold (HypFIG 4C). As a result, the embryo changes from a lima-bean-like shape to a long, thin tube at threefold stage (see IntroFIG7). At the beginning of elongation, circumferential actin and tubulin filament bundles form in all hypodermal cells and are associated with the apical membranes. Actin filaments are anchored to adherens junctions at lateral cell margins via cadherin-catenin complexes. As elongation proceeds, actin filaments in the seam cells shorten (Costa et al., 1997; Costa et al., 1998; Priess and Hirsh, 1986). It has been suggested that the lateral hypodermal cells (seam cells) actively drive hypodermal elongation and that the contractile force that they generate is transmitted to the rest of the hypodermis via adherens junctions (Ding et al., 2004). Elongation proceeds at about 50 μm/hr and is completed at around 600 minutes. The circumferential actin bundles disappear after elongation is complete (Priess and Hirsh, 1986; Costa et al., 1997). The integrity of the hypodermal sheet is essential for successful elongation; it is reinforced by the embryonic sheath, which is secreted over the surface of the embryo before elongation, and by microtubule bundles in dorsal and ventral hypodermal cells (Priess and Hirsh, 1986; Ding et al., 2004). These circumferentially organized microtubules probably distribute the force generated by actomyosin contraction. Intact muscle structure and attachments (fibrous organelles) that link muscle and hypodermis are required for continuation of the process in later stages of elongation. Mutants that show complete absence of muscle function fail to elongate beyond the twofold stage. Once elongation is completed, the embryo secretes a cuticle that maintains the body shape and replaces the embryonic sheath. The hypodermal syncytia are formed by secondary cell fusions in the embryo, most of which take place as the embryos elongate (Podbilewicz and White, 1994; Podbilewicz, 2000, 2006). These cell fusions generally follow an order, although it can vary (Mohler et al., 1998). Fusion between cells takes place by two sequential processes; initial formation of a pore and expansion of the opening by internalization of the fusing cell membranes (Mohler et al., 1998). As the embryo is enclosed ventrally, about 340 minutes after first cleavage (before comma stage), the first cell-to-cell fusion occurs between two anterior ventral cells to initiate formation of hyp 7 syncytium (HypTABLE 2) (Podbilewicz and White, 1994). Fusion events then progress towards the posterior part of the elongating embryo, followed by fusion of the dorsal and ventral syncytia (Singh and Sulston , 1978; Priess and Hirsh, 1986; Hedgecock et al., 1987). Thus, at hatching, a total of 23 cells have joined to make the hyp 7 syncytium that covers most of the dorsal surface and parts of the ventral surface of the head and the tail (HypFIG 5). The anterior ring of hyp 7 covers the area around the excretory canal, and another posterior ring covers the post-anal region. Between these two rings, hyp 7 syncytium is not cylindrical at this time because of the presence of a lateral row of seam cells and a ventral row of P cells on each side (HypFIG 5A). The hyp 6 syncytium is initially formed by two separate fusions that then join to make the annular hyp 6 during elongation phase of embryogenesis. At this time, hyp 6 is connected to hyp 5 and hyp 7 by adherens junctions (HypFIG 5D) (Sulston et al., 1983; Podbilewicz and White, 1994; Shemer and Podbilewicz, 2000). At the end of embryogenesis the hyp 6 ring contains four dorsal and two ventral nuclei, while the hyp 7 ring contains six ventral, two dorsal and fifteen dorsolateral nuclei (HypFig 5A). The hyp 5 syncytium forms after the left and right lateral hyp 5 cells migrate and fuse. The left and right ventral hyp 4 cells fuse to initiate formation of the hyp 4 syncytium. The two cells that make the hyp 10 syncytium in the tail fuse between 1.5-fold and threefold stages. HypTABLE 2: Timing of hypodermal fusion events in the embryo. Time is given in minutes after first cleavage or the stage of the embryo. For cell numbers refer to HypFIG 2. The hyp 6 syncytium is initially formed by two separate fusions (between cells I, II, III and IV and cells V and VI) that then join to make the annular hyp 6 during the elongation phase of embryogenesis. HypFIG 5: Hypodermis in the early L1 stage (until 5 hr post-hatching). A. Left lateral view of the whole body. At this stage, hyp 7 makes two complete rings wrapping the posterior of the head and the postanal region. Between these two rings, hyp 7 covers only the dorsal and lateral of portions of the body, whereas seam cells and P cells occupy the ventrolateral regions. (Inset) H0, H1, H2, T, hyp 1-6 and tail hypodermis are removed. (Dark circles) Position of nuclei. B. Animal filleted at the ventral midline. hyp 3 and tail hypodermis (hyp 11, hyp 10) are removed. A single row of ten seam cells is located on each side, extending from the hyp 6-hyp 5 junction to the hyp 7-hyp 8 junction. Anterior to hyp 7, hyp 4, hyp 5 and hyp 6 make separate rings of hypodermal tissue. P cells are colored according to the fate of their descendants: P1-P4 and P9-P12 give rise to hypodermis and neurons, whereas P5-P8 generate hypodermis and vulva. (d) Anterior deirid; (e) excretory pore; (a) anus. C. Animal filleted at the dorsal midline. P1-P12 are aligned in pairs along the ventral midline from anus to the V1-V2 junction. (a) Anus; (ep) excretory pore; (ad) anterior deirid; (ph) phasmid. D. Epifluorescent image of a transgenic, early L1-stage animal expressing the ajm-1::GFP reporter, ventral oblique view. Visible are apical borders between seam cells, hypodermal cells and P cells as are left side seam cells and P-cell pairs. (Green dotted lines) The pharynx; (vm) ventral midline. Original magnification, 600x. (Strain source: H. Yu and P. W. Sternberg.)
3 Post-embryonic Development of the Hypodermis During larval development, the body of the animal grows significantly, without many changes in the ectodermal body plan. The hyp 7 syncytium, which covers most of the body, must increase in volume accordingly. The seam cells must also grow to adapt to the increasing body size. To accommodate this growth, an additional 116 cells are added to hyp 7 during postembryonic development from P- and seam-cell lineages and from hyp 6 (HypFIG 1B&C). The seam cells, excluding H0, undergo a stem-cell division at the beginning of each larval stage and contribute additional 98 nuclei to the hyp 7 syncytium (HypFIG 6, 7 & 8 ). Soon after they are born, the daughters of seam stem cells that will become part of hyp 7 endoreduplicate their DNA and become tetraploid (Hedgecock and White, 1985). In contrast, the embryonically derived hyp 7 nuclei remain diploid. HypFIG 6: Division of seam blast cells in L1. Epifluorescent image of transgenic animals expressing the ajm-1::GFP reporter in the hypodermis. (Strain source: H. Yu and P.W. Sternberg.) A. Left lateral view. Approximately 5 hours after hatching, the seam cells round up and divide. H0 does not divide at any stage. In this animal H1, H2, V6 and T have not yet divided. Anterior daughters (stars) of V2-V5 have started to insert themselves between the P cells, separating them from one another. (P) Six left-side cells of the P1-P12 pairs. (a) Anus; (inset) V5 is generally the first seam cell to divide. B. Left lateral oblique view. Approximately 7 hours after hatching. The cytoplasmic processes of the anterior daughters of V2-V6 open up the adherens junctions between the neighboring P cells in each row, isolating each P-cell pair. Some of these cells have either already fused with hyp 7 (arrow) or are in the process of fusing (stars). (Arrowheads) Dissolving adherens junctions of these cells. H1, H2, V1 and T have just divided. Six left-side cells of the P1-P12 pairs are marked with P. (vm) Ventral midline; (a) anus. C. Left lateral view. Approximately 8 hours after hatching and 3 hours after they are generated, anterior descendants of seam cells fuse to hyp 7, with their nuclei remaining close to the seam cells on each side (not shown). (a) Anus. D. Left lateral view. Each left and right pair of P cells is detached from its anterior-posterior neighbors by fusion of the anterior seam descendants with hyp 7, producing six pairs of isolated P cells. P1/2 have started to rotate to align along the midline. (Stars) Anterior daughters of V6 and T are in the process of fusion with hyp 7. (a) Anus. HypFIG 7: Larval divisions of seam cells. The pattern of division, fusion, and coupled elongation of seam cells repeats itself in each larval stage until mid L4. A. DIC image of the midbody of an early L2-stage animal, lateral view. The anterior daughters of V5 generate the posterior deirid sensilla (Pd). (Orange line) Seam cells; arrow points to two nuclei of hyp 7. B-F. Epifluorescent images of animals from a strain expressing the ajm-1::GFP reporter. Original magnification, 600x. (Strain source: H. Yu and P.W. Sternberg.) B. Epifluorescent image of the same animal as in A. Visible are apical boundaries of dividing seam cells. C. Epifluorescent image, left lateral view. Shown is the same body region as in A and B, although at a slightly later time in L2 stage. All seam cells have generated daughters (anterior daughters are shown with stars and posterior deirid cells [Pd]) by this time, although none of them have fused with hyp 7 yet. D. Epifluorescent image, left lateral view. Division of seam cells at L3 stage. Stars indicate anterior daughters that will fuse with hyp 7. E. Epifluorescent image, left lateral view. Slightly before mid-L4 stage, seam cells have completed their final division, but have not yet fused to each other to make one syncytium. Around mid-L4, each seam cell fuses with its seam neighbors. F. Epifluorescent image, left lateral view. Young adult animal. The adherens junctions between seam cells have dissolved generating one syncytial seam with 16 nuclei on each side of the animal and spanning the region between phasmid (arrowhead) and hyp 5. HypFIG 8A-F: Hypodermal development during larval stages. Epifluorescent image of transgenic animals expressing the Y37A1B.5::GFP reporter in the hypodermis. Original magnification, 600x. (Strain source: The Genome BC C. elegans gene expression consortium; McKay et al., 2004.) A&B. L1 larvae. A. Dorsal view. A thin layer of hypodermis continuous with the dorsal hypodermal ridge (white arrow) and lateral hypodermis covers the dorsal muscle quadrants (stars) on both sides. B. Right lateral view. The nuclei of the hyp 6 and hyp 7 syncytia are located in the dorsal and ventral hypodermal ridges in the head (white arrows). However, along the body, hyp 7 nuclei are placed eccentrically and close to the seam cells as a result of the migration of dorsal cells during intercalation (arrowheads) (see HypFIG 2 and HypFIG 5A). C. L1 larva and ongoing seam cell divisions (left lateral side). Anterior daughters of the V2 - V6 seam cells have joined the hyp 7 syncytium, separating P cells from one another and increasing the number of nuclei on the lateral side of hyp 7 (arrowheads). Anterior seam progenitors (e.g., V1) are still dividing. D. Early-L2 larva, left lateral side. The number of hyp nuclei on the lateral sides has nearly doubled after H1-H2, V1-V6, and T seam divisions in L1. (Top left inset) Enlarged DIC image of the same animal. The large nuclei with prominent nucleoli of hyp7 (white arrowheads) are located close to the eye-shaped seam cells (black arrows). (Top right inset) Overlaid DIC and epifluorescent images of the same region. Seam cells do not express this GFP reporter gene. (Bottom inset) Epifluorescent image of a later-L2-stage animal showing duplicating seam cells at this time. E. Late-L3 larva, left lateral side. Further divisions of seam cells at early L3 contribute 26 more nuclei to hyp 7 on the lateral side. Pnp divisions contribute more nuclei to the ventral hyp 7, increasing the nuclei number in the ventral hypodermal ridge (arrow). F. Adult, graphic depiction of the medial and left lateral side nuclei of the hyp 7 syncytium. Medial nuclei are lighter colored while lateral nuclei are brighter beige. The seam syncytium (orange) is shown as labeled with each precursor. (e) embryonic origin; (L) larval origin; (P) P-cell derived. The number signs next to some of the nuclei correspond to those in HypFIG 2 panel D. HypFIG 8G: Graphic depiction of the postembryonic development of the left lateral hypodermis. Bars on each panel correspond to 20 μm. The number signs next to some of the hyp nuclei correspond to those in HypFIG 2 panel D. These are the embryonically-derived hyp nuclei and are colored as light beige, while postembryonically-born nuclei are colored darker. The colors of the remaining nuclei correspond to WA color code. The names of the postdeirid ganglion nuclei are shown only in the third (22 hr) panel. Based on Fig 9 in Sulston and Horvitz, 1977. At hatching, the 12 unfused ventral hypodermal cells (P1-P12) are positioned as two parallel rows, with each cell confronting its bilateral homolog along the ventral midline (HypFIG 5C&D). In L1, these cells interdigitate to form a single row of cells on the ventral side (HypFIG 9) (Sulston and Horvitz, 1977). P1-P12 ventral cells divide soon after this, and the anterior daughters detach from the epithelium and become neuroblasts (Sulston and Horvitz, 1977; Hedgecock et al, 1987). The posterior daughters of P1, P2 and P9-12 fuse with hyp 7 at the end of the L1 stage, whereas the posterior daughters of P3-P8 divide at the L3 stage to make 12 cells. Of these, the daughters of P3p, P4p, and P8p fuse with hyp 7; the daughters of P5p, P6p and P7p become vulva precursor cells (HypFIG 1C). HypFIG 9: Division of P cells. All are epifluorescent images from the same strain as in HypFIG 6. Original magnification, 600x. A. Lateral view. Newly generated seam cells elongate (arrows) over their hypodermal sisters and restore their mutual contact with their neighbors. B. Approximately 9 hours after hatching, ventral view, slightly tilted to the left. After seam-cell descendants fuse to hyp 7, the P cell migrates into the ventral cord, starting from the anteriormost pair and proceeding posteriorly (Sulston, 1976). At the same time, P-cell pairs rotate by 90° to form a single row along the ventral midline and retract their lateral margins. For the P1/P2 and P11 pairs this rotation is biased, whereas for the others the rotation can occur in either direction (Sulston and Horvitz,1977; Delattre and Felix, 2001). C. Late-L1 stage, ventral view, slightly tilted to the left. All P descendents, except P3p-P8p, either fuse to hyp 7 or become ventral cord motor neurons (arrows point to dissolving adherens junctions in these cells). D. L2 stage, ventral view, slightly tilted to the left. The positions of the nuclei of P2p, P9p-P1p and P12pa that have already joined hyp 7 are shown by pink ovals drawn over the epifluorescent image. The nuclei of the hypodermal cells reside in the ventral hypodermal ridge (when P-cell divisions are completed, there are 12 hypodermal nuclei in the ridge between the retrovesicular ganglion and the anus). The newly born ventral cord motor neurons are situated next to the hypodermal ridge along the ventral midline (not shown). P3p-P8p still have more divisions to go through in L3 stage. (vm) Ventral midline.
> 4 Adult Hypodermis In adult C. elegans, the hypodermis is composed of the main body syncytium, hyp 7 and smaller hypodermal cells in the head and the tail, numbered from hyp 1 to hyp 5 and hyp 8 to hyp 11 (also, hyp 13 in the male). In the adult, hyp 7 contains 139 nuclei and envelops the whole body, except for the extreme head and tail. The hypodermal cells of the head and tail are generated during embryogenesis and acquire no additional nuclei post-embryonically. The lips anterior to the buccal cavity are covered by three narrow, concentric rings of hypodermal cells (hyp 1, hyp 2 and hyp 3), which serve to unite the outer hypodermis to the epithelial lining of the digestive tract (HypFIG 10 and HypFIG 11, InterFIG 1). hyp 1 forms the innermost ring encircling the tip of the lips and connects to the arcade cells of the buccal cavity. hyp 3 forms the outermost ring and connects to hyp 2 on the inside and hyp 4 on the outside. All five hypodermal cells of the anterior head are syncytial, containing two to three nuclei (HypTABLE 1). Because of their posterior translocation during embryogenesis, the structures of these cells are similar to the arcade cells, such that their cell bodies are situated posterior to the concentric rings and connected to them by thin cytoplasmic processes (InterFIG 2). HypFIG 10: Anterior hypodermis. A. Three concentric rings of hypodermal cells (hyp 1, hyp 2 and hyp 3) constitute the hypodermis of the extreme anterior of the head. The innermost one, hyp 1, connects the hypodermis to the arcade cells and the pharyngeal epithelium. Not shown are posterior arcade and the pharyngeal epithelium. B. Transmission electron micrograph (TEM) of the lateral lip, horizontal section. The endings of the head sensilla and anterior head muscles fit between the external (hyp 3 and hyp 4) and internal (hyp 1 and hyp 2) hypodermal tissues. Inside the buccal cavity, anterior and posterior arcade cells connect the buccal hypodermis to the pharyngeal epithelium. (For comparison of the positions of the anterior hypodermal and arcade cells refer to IntFIG 3.) Color overlay has been added atop the TEM image to indicate cell types involved. Bar, 1 μm. (Image source: N533 [Hall] negative C240.) C. Epifluorescent image of transgenic, adult-stage animal expressing the ajm-1::GFP reporter in the hypodermis, lateral view. hyp 2 and hyp 3 make adherens junctions (white arrowhead) at the tip of the lip, with the hyp 2 ring covering the interior and the hyp 3 ring covering the exterior surfaces. hyp 2 and hyp 1 rings make adherens junctions where they meet inside the buccal cavity (arrow). hyp 3 and hyp 4 rings join by adherens junctions on the outside surface (gray arrowhead). hyp 6 has already fused with hyp 7 at this stage. Original magnification, 600x. (Strain source: H. Yu and P. W. Sternberg.) HypFIG 11A-C: Hypodermis of the head. A. Localization of hypodermal and seam nuclei in a 430-minutes (after first cleavage), tadpole-stage embryo, view from dorsal. Anterior hypodermal cells later migrate, acquiring shapes similar to the arcade cells. Numbers correspond to the hyp cells (1 is hyp 1, etc.). Darker nuclei are the closest to the dorsal side. (e) Excretory pore; (a) anus (based on Sulston et al., 1983). B. The localization of anterior hyp and seam-cell nuclei in an L2 stage animal, left lateral view. Each nucleus is schematically drawn over the DIC image. Solid-colored nuclei lie in the lateral planes and transparent ones in the midplane. Left lateral (posterior) and midplane (anterior) aspects of the DIC image are separated by a thin black line. The right side is a mirror image of the left, except there is no hyp 2 on the right. At this stage, the anterior hypodermal cell somata (hyp 1-6) are situated posterior to the anterior rings because of embryonic cell migrations (see HypFIG 5 and HypFIG 10). The positions of nuclei are determined from TEM sections of the N2T animal (MRC archive), and there may be slight variations between individual animals. C. DIC image of the same animal as in B, from a strain expressing the Y37A1B.5::GFP reporter in the hypodermis (top panel), with an epifluorescent image overlain on the DIC image (bottom panel). Hypodermal nuclei that are visible at this plane are marked by arrowheads (top panel); black arrow marks a body wall muscle nucleus (BWmu). Remaining nuclei belong to arcade cells, neurons and glia. Nuclei of hyp 6 and hyp 7 cells expressing GFP are located in dorsal and ventral ridges around and posterior to the anterior bulb of the pharynx (arrowheads, right panel). The white arrow points to the junction between hyp 5 (no GFP expression) and hyp 6 (with GFP expression). Original magnification, 600x. (Strain source: The Genome BC C. elegans gene expression consortium; McKay et al., 2004.) HypFIG 11D-F: Hypodermis of the head. D&E. Epifluorescent images of transgenic L1-stage animals expressing the ajm-1::GFP reporter in the hypodermis. (Strain source: H. Yu and P. W. Sternberg.) D. Ventral view. hyp 6 and hyp 7 syncytia are connected by adherens junctions, but have not yet fused. hyp 7 makes a complete ring around the posterior of the head, isolating the excretory pore (e). The adherens junctions in ventral hyp 7 on both sides of the excretory pore have almost completely dissolved (arrowheads). E. Lateral oblique view. Anterior end of seam cells (of H0) extend to hyp 6-hyp 5 junction. The excretory pore is aligned with the anterior deirid (d) and the junction between H1 and H2 seam cells. hyp 7 and hyp 6 make complete rings passing underneath the seams. F. TEM, longitudinal section through the anterior of the head of an adult animal as shown in inset. The ventral nuclei and cytoplasm of the hyp 4 syncytium are colored (pink) over the TEM image. The outer hyp 4 ring (bracket) encircles the head between the level of arcade-pharyngeal epithelium junction and near the tip of the lips on the outside. The hyp 5 ring (not shown) is posterior to the hyp 4 ring. (Image source: [Hall] B156-7778.) Bar, 1 μm. HypFIG 11G: Epithelial nuclei in the head. Top 2 panels. Graphic rendition of positions of hypodermal and arcade cell nuclei along the head. Nuclei positions were deduced from N2T TEM sections (print numbers are indicated along a ruler above and below the left and right side images respectively). Dark green ovals indicate head muscle nuclei (only four of the body wall muscle nuclei are shown). Two of the dorsal hyp 6 and hyp 7 nuclei are not shown. Bottom panel. Epifluorescent images of a transgenic animal expressing a hypodermal reporter, left lateral view. Left panel shows medial plane hypodermal nuclei, middle panel shows superficial (lateral) plane hypodermal nuclei and right panel shows overlay of the two panels. The four tail tip hypodermal cells, hyp 8-11, are generated in early embryogenesis. During the elongation phase, they acquire their characteristic tapered shapes. This tapered shape continues throughout all stages of the hermaphrodite; it transforms into a complex fan-like shape in mid-L4 stage in males (Nguyen et al., 1999). hyp 8-10 closely fit onto one another in a succeeding fashion to make up the anal hypodermal ridge, which stretches between the dorsorectal ganglion and tail tip (HypFIG 12). hyp 11 lies just above the anal hypodermal ridge, separated from it by a basal lamina. The nuclei of hyp 8-10 lie within the ridge towards the anterior of each cell, whereas the nucleus of hyp 11 is located asymmetrically on the dorsal left side. Adherens and gap junctions link the neighboring hypodermal cells of the tail (see also Gap Junctions). The neuronal processes that extend to the extreme tail tip either penetrate through (PVR, PDB, PHC) the hypodermal cells or run next to them (PLM, PLN, PVR, PHC), sharing a basal lamina (Nguyen et al., 1999). Behind the phasmid openings, this basal lamina eventually ends, and the extreme tail whip consists of closely packed hypodermal (hyp 9 and hyp 10) and neuronal processes (Nguyen et al., 1999). HypFIG 12: Tail hypodermis. A. Tail hypodermal cells, lateral view. (Red) hyp 8; (purple) hyp 9; (light green) hyp 10; (yellow) hyp 11. (Green circle) Phasmid opening; (s) seam. hyp 8-10 fit into one another in a succeeding fashion, whereas hyp 11 wraps over the dorsal side. hyp 8 and hyp 11 abut the hyp 7 syncytium at their anterior border and make adherens junctions and gap junctions to it. (Dark circles) Nuclei (based on Nguyen et al., 1999). Asterisks in panels A, C, D and G indicate posteriormost hyp 7 nuclei. B. Epifluorescent image of an L1-stage animal from a strain expressing the ajm-1::GFP reporter showing the apical borders of tail hypodermal cells, ventral view. Original magnification 600x. (Strain source: H. Yu and P. W. Sternberg.) C. DIC image of the same animal as in B. Shown is the position of each hypodermal nucleus as well as the posteriormost seam cell. D. Epifluorescent image of an adult animal showing hyp 7 in tail. E. Epifluorescent image of an L2-stage animal from a strain expressing the ajm-1::GFP reporter showing the apical borders of tail hypodermal cells, left lateral view. Original magnification 600x. (Strain source: H. Yu and P. W. Sternberg.) F. DIC image of the same animal as in D. The position of each hypodermal nucleus, as well as the posteriormost seam cell, is shown on the middle-left plane. The hyp 11 nucleus is becoming visible. G. DIC image of the same animal as in D and E (the middle plane). hyp 8-10 nuclei are visible, but the hyp 11 nucleus is not. The two post-anal, ventral hyp 7 nuclei are seen, as well as nuclei of some lumbar ganglia neurons. 5 List of Hypodermal Cells (For cell name/number correspondence see HypFIG 1, HypFIG 2 and below. Dorsal nuclei locations are post-intercalation: LL: lateral left; LR: lateral right. V1/2, D1/2 etc indicate stochastic fates.)
> 1. Head (anterior to the excretory pore; all embryonic) hyp 1 (V) - ABarappaapa hyp 1 (DL) - ABalpaapppa hyp 1 (DR) - ABaraaapppp hyp 2 (V) - ABalpapaaap hyp 2 (DL) - ABalpaapppp hyp 3 (D1/2) - ABplaapaaaa hyp 3 (D1/2) - ABpraapaaaa hyp 4 (D) - ABarpapapa hyp 4 (V1/2) - ABpraappaa hyp 4 (V1/2) - ABplaappaa hyp 5 (L) - ABplaaapp hyp 5 (R) - ABarpappap hyp 6 (D1) - ABplaaaapa hyp 6 (D2) - ABarpaapa hyp 6 (D3) - ABplaaaapp hyp 6 (D4) - ABarpapapp hyp 6 (V1/2) - ABplaappap hyp 6 (V1/2) - ABpraappap hyp 7 (D1) - ABarpaapap hyp 7 (D2) - ABarpaappa hyp 7 (V18/19) - ABpraapppa hyp 7 (V18/19) - ABplaapppa 2. Body (posterior to the excretory pore) Embryonic: hyp 7 (D3) - LR nucleus. ABarpaappp hyp 7 (D4) - LL nucleus. ABarppaapa hyp 7 (D5) - LR nucleus. ABarpppapa hyp 7 (D6) - LL nucleus. Cpaaaa hyp 7 (D7) - LR nucleus. Caaaaa hyp 7 (D8) - LL nucleus. Cpaaap hyp 7 (D9) - LR nucleus. Caaaap hyp 7 (D10) - LL nucleus. Cpaapa hyp 7 (D11) - LR nucleus. Caaapa hyp 7 (D12) - LL nucleus. Cpaapp hyp 7 (D13) - LR nucleus. Caaapp hyp 7 (D14) - LL nucleus. Cpapaa hyp 7 (D15) - LR nucleus. Cpapap hyp 7 (D16) - LL nucleus. Cpappd hyp 7 (D17) - LR nucleus. Caappd hyp 7 (V20) - ABplaapppp hyp 7 (V21) - ABpraapppp Postembryonic: Ventral (P lineage) hyp 7 (V1) - P1.p hyp 7 (V2) - P2.p hyp 7 (V3) - P3.pa hyp 7 (V4) - P3.pp hyp 7 (V5) - P4.pa hyp 7 (V6) - P4.pp | hyp 7 (V7) - P8.pa hyp 7 (V8) - P8.pp hyp 7 (V9) - P9.p hyp 7 (V10) - P10.p hyp 7 (V11) - P11.p hyp 7 (V12) - P12.pa (aka hyp 12) Lateral (seam blast lineage) hyp 7 (LL1) - H1L.apa hyp 7 (LL2) - H1L.appa hyp 7 (LL3) - H1L.p hyp 7 (LL4) - H2L.ap hyp 7 (LL5) - H2L.pa hyp 7 (LL6) - H2L.ppa hyp 7 (LL7) - H2L.pppa hyp 7 (LL8) - V1L.a hyp 7 (LL9) - V1L.paa hyp 7 (LL10) - V1L.papa hyp 7 (LL11) - V1L.pappa hyp 7 (LL12) - V1L.ppa hyp 7 (LL13) - V1L.pppa hyp 7 (LL14) - V1L.ppppa hyp 7 (LL15) - V2L.a hyp 7 (LL16) - V2L.paa hyp 7 (LL17) - V2L.papa hyp 7 (LL18) - V2L.pappa hyp 7 (LL19) - V2L.ppa hyp 7 (LL20) - V2L.pppa hyp 7 (LL21) - V2L.ppppa hyp 7 (LL22) - V3L.a hyp 7 (LL23) - V3L.paa hyp 7 (LL24) - V3L.papa hyp 7 (LL25) - V3L.pappa hyp 7 (LL26) - V3L.ppa hyp 7 (LL27) - V3L.pppa hyp 7 (LL28) - V3L.ppppa hyp 7 (LL29) - V4L.a hyp 7 (LL30) - V4L.paa hyp 7 (LL31) - V4L.papa hyp 7 (LL32) - V4L.pappa hyp 7 (LL33) - V4L.ppa hyp 7 (LL34) - V4L.pppa hyp 7 (LL35) - V4L.ppppa hyp 7 (LL36) - V5L.a hyp 7 (LL37) - V5L.ppa hyp 7 (LL38) - V5L.pppa hyp 7 (LL39) - V5L.ppppa hyp 7 (LL40) - V5L.ppppp hyp 7 (LL41) - V6L.a hyp 7 (LL42) - V6L.paa hyp 7 (LL43) - V6L.papa hyp 7 (LL44) - V6L.pappa | hyp 7 (LL40) - V5L.ppppp hyp 7 (LL45) - V6L.ppa hyp 7 (LL46) - V6L.ppppa hyp 7 (LL47) - TL.aa hyp 7 (LL48) - TL.apaa hyp 7 (LL49) - TL.apap hyp 7 (LR18) - V2R.pappa hyp 7 (LR19) - V2R.ppa hyp 7 (LR20) - V2R.pppa hyp 7 (LR21) - V2R.ppppa hyp 7 (LR22) - V3R.a hyp 7 (LR23) - V3R.paa hyp 7 (LR24) - V3R.papa hyp 7 (LR25) - V3R.pappa hyp 7 (LR26) - V3R.ppa hyp 7 (LR27) - V3R.pppa hyp 7 (LR28) - V3R.ppppa hyp 7 (LR29) - V4R.a hyp 7 (LR30) - V4R.paa hyp 7 (LR31) - V4R.papa hyp 7 (LR32) - V4R.pappa hyp 7 (LR33) - V4R.ppa hyp 7 (LR34) - V4R.pppa hyp 7 (LR35) - V4R.ppppa hyp 7 (LR36) - V5R.a hyp 7 (LR37) - V5R.ppa hyp 7 (LR38) - V5R.pppa hyp 7 (LR39) - V5R.ppppa hyp 7 (LR40) - V5R.ppppp hyp 7 (LR41) - V6R.a hyp 7 (LR42) - V6R.paa hyp 7 (LR43) - V6R.papa hyp 7 (LR44) - V6R.pappa hyp 7 (LR45) - V6R.ppa hyp 7 (LR46)- V6R.ppppa hyp 7 (LR47) - TR.aa hyp 7 (LR48) - TR.apaa hyp 7 (LR49) - TR.apap 3. Tail (posterior to anus; all embryonic) hyp 7 (V22/23) - ABplappppa (aka hyp 13) hyp 7 (V22/23) - ABprappppa (aka hyp 13) hyp 8/9 - ABplpppapap hyp 8/9 - ABprpppapap hyp 10 (V1/2) - ABplppppppp hyp 10 (V1/2) - ABprppppppp hyp 11 - Cpappv Entire hyp7 syncytium
HypFIG Cell List: Hypodermal nuclei in newly hatched L1. Adapted from Sulston et al., 1983. Brackets indicate pairs of nuclei, of bilaterally symmetrical origin, whose anterior-posterior ordering is uncertain. Note ventral hyp 1 and hyp 2 are lodged between two ventral hyp 6 cells but do not belong to the brackets covering these two hyp 6 cells. (NB. Caaa & Cpaa and ABarppaapa & ABarpppapa are moved to correct positions in this figure.) 6 References Bossinger, O., Klebes, A., Segbert, C., Theres, C. and Knust, E. 2001. Zonula adherens formation in Caenorhabditis elegans requires dlg-1, the homologue of the Drosophila gene discs large. Dev. Biol. 230: 29-42. Article Chin-Sang, I.D., George, S.E., Ding, M., Moseley, S.L., Lynch, A.S. and Chisholm, A.D. 1999. The ephrin VAB-2/EFN-1 functions in neuronal signaling to regulate epidermal morphogenesis in C. elegans. Cell 99: 781-790. Article Chin-Sang, I.D. and Chisholm, A.D. 2000. Form of the worm: genetics of epidermal morphogenesis in C. elegans. Trends Genet. 16: 544-551. Abstract Chisholm, A.D. and Hardin, J. 2005. Epidermal morphogenesis. In WormBook (ed. The C. elegans Research Community) doi/10.1895/wormbook.1.35.1. Article Costa, M., Draper, B.W. and Priess, J.R. 1997. The role of actin filaments in patterning the Caenorhabditis elegans cuticle. Dev. Biol. 184: 373-384. Article Costa, M., Raich, W., Agbunag, C., Leung, B., Hardin, J. and Priess, J.R. 1998. A putative catenin-cadherin system mediates morphogenesis of the Caenorhabditis elegans embryo. J. Cell Biol. 141: 297-308. Article Cowan, A.E. and McIntosh, J.R. 1985. Mapping the distribution of differentiation potential for intestine, muscle, and hypodermis during early development in Caenorhabditis elegans. Cell 41: 923-932. Abstract Delattre, M. and Felix, M.A. 2001. Development and evolution of a variable left-right asymmetry in nematodes: The handedness of P11/P12 migration. Dev. Bio. 232: 362-371. Article Ding, M., Woo, W-M. and Chisholm, A.D. 2004. The cytoskeleton and epidermal morphogenesis in C.elegans. Exp. Cell Res. 301: 84-90. Abstract Fay, D.S., Stanley, H.M., Han, M. and Wood, W.B. 1999. A Caenorhabditis elegans homologue of hunchback is required for late stages of development but not early embryonic patterning. Dev. Biol. 205: 240–253. Article Gendreau, S.B., Moskowitz, I.P.G., Terns, R.M and Rothman, J. H. 1994. The potential to differentiate epidermis is unequallydistributed in the AB lineage during early embryonic development in Caenorhabditis elegans. Dev. Biol. 166: 770-781. Abstract George, S., Simokat, K., Hardin, J. and Chisholm, A.D. 1998. The vab-1 Eph receptor tyrosine kinase functions in neural and epithelial morphogenesis in C. elegans. Cell 92: 633-643. Article Greenwald, I. 1997. Development of the vulva. In C. elegans II (ed. D.L. Riddle et al.) Chapter 19. pp 519-541. Cold Spring Harbor Laboratory Press, Cold Spring Harbor, New York. Article Hedgecock, E.M. and White, J.G. 1985. Polyploid tissues in the nematode Caenorhabditis elegans. Dev. Biol. 107: 128-133. Abstract Hedgecock, E.M., Culotti, J.G., Hall, D.H. and Stern, B.D. 1987. Genetics of cell and axon migrations in Caenorhabditis elegans. Development 100: 365-382. Article Heid, P.J., Raich, W.B., Smith, R., Mohler, W.A., Simokat, K., Gendreau, S.B., Rothman, J.H. and Hardin, J. 2001. The zinc finger protein DIE-1 is required for late events during epithelial cell rearrangement in C. elegans. Dev. Biol. 236: 165-180. Article Johnstone, I.L. and Barry, J.D. 1996. Temporal reiteration of a precise gene expression pattern during nematode development. EMBO J. 15: 3633-3639. Article Koppen, M., Simske, J.S., Sims, P.A., Firestein, B.L., Hall, D.H., Radice, A.D. , Rongo, C. and Hardin, J.D. 2001. Cooperative regulation of AJM-1 controls junctional integrity in Caenorhabditis elegans epithelia. Nat. Cell Biol. 3: 983-991. Abstract Kramer, J. 1997. Extracellular matrix. In C. elegans II (ed. D.L. Riddle et al.). Chapter 17. pp 471-500. Cold Spring Harbor Laboratory Press, Cold Spring Harbor, New York. Article Labouesse, M. 1997. Deficiency screen based on the monoclonal antibody MH27 to identify genetic loci required for morphogenesis of the Caenorhabditis elegans embryo. Dev. Dyn. 210:19-32. Article Michaux, G., Legouis, R. and Labouesse, M. 2001. Epithelial biology: lessons from Caenorhabditis elegans. Gene 277: 83-100. Abstract McKay, S.J., Johnsen, R., Khattra, J., Asano, J., Baillie, D.L., Chan, S., Dube, N., Fang, L., Goszczynsk,i B., Ha, K., Halfnight, E., Hollebakken, R., Huang, P., Hung, K., Jensen, V., Jones, S.J.M., Kai, H., Li, D., Mah,, A., Marr, M., McGhee, J., Newbury, R., Pouzyrev, A., Riddle, D.R., Sonnhammer, E., Tian, H., Tu, D., Tyson, J., Warner, A., Wong, K., Zhao, Z. and Moerman, D.G. 2004. Gene expression profiling of cells, tissues, and developmental stages of the nematode C. elegans. Cold Spring Harbor Symp. Quant. Biol. 68: 159-169. Abstract Mohler, W.A., Simske, J.S., Williams-Masson, E.M., Hardin, J.D. and White, J.G. 1998. Dynamics and ultrastructure of developmental cell fusions in the Caenorhabditis elegans hypodermis. Curr. Biol. 8: 1087-1090. Article Nguyen, C.Q., Hall, D.H., Yang, Y. and Fitch, D.H.A. 1999. Morphogenesis of the Caenorhabditis elegans male tail tip. Dev. Biol. 207: 86-106. Article Podbilewicz, B. 2000. Membrane fusion as a morphogenetic force in nematode development. Nematol. 2: 99-111. Abstract Podbilewicz, B. and White, J.G. 1994. Cell fusions in the developing epithelial of C. elegans. Dev. Biol. 161: 408-424. Abstract Podbilewicz, B. 2006 Cell fusion. In WormBook (ed. The C. elegans Research Community) WormBook, doi/10.1895/wormbook.1.52.1. Article Priess, J.R. and Hirsh, D.I. 1986. Caenorhabditis elegans morphogenesis: the role of the cytoskeleton in elongation of the embryo. Dev. Biol. 117: 156-173. Abstract Shemer, G. and B. Podbilewicz. 2000. Fusomorphogenesis: cell fusion in organ formation. Dev. Dyn. 218: 30-51. Article Simske, J.S. and Hardin, J. 2001. Getting into shape: epidermal morphogenesis in Caenorhabditis elegans embryos. Bioessays 22: 12-23. Article Singh, R.N. Sulston, J.E. 1978. Some observations on moulting in Caenorhabditis elegans. Nematologica 24: 63-71. Abstract Sulston, J.E. 1976. Post-embryonic development in the ventral cord of Caenorhabditis elegans. Phil. Trans. Royal Soc. London 275B: 287-298. Article Sulston, J.E. and Horvitz, H.R. 1977. Post-embryonic cell lineages of the nematode Caenorhabditis elegans. Dev. Biol. 56: 110-156. Article Sulston, J.E., Schierenberg, E., White, J.G. and Thomson, J.N. 1983. The embryonic cell lineage of the nematode Caenorhabditis elegans. Dev. Biol. 100: 64-119. Article White, J. 1988. The Anatomy. In The nematode C. elegans (ed. W.B. Wood). Chapter 4. pp 81-122. Cold Spring Harbor Laboratory Press, Cold Spring Harbor, New York. Abstract Williams-Masson, E.M., Malik, A.N. and Hardin J. 1997. An actin-mediated two-step mechanism is required for ventral enclosure of the C. elegans hypodermis. Development 124: 2889-2901. Article Williams-Masson, E.M., Heid, P.J., Lavin, C.A. and Hardin, J. 1998. The cellular mechanism of epithelial rearrangement during morphogenesis of the Caenorhabditis elegans dorsal hypodermis. Dev. Biol. 204: 263-276. Article Witze, E. and Rothman, J.H. 2002. Cell fusion: an EFFicient sculptor. Curr. Biol. 12: R467-R469. Article Wright, K.A. 1987. The nematode’s cuticle-Its surface and the epidermis: Function, homology, analogy-A current consensus. J. Parasitol. 73: 1077-1083. Abstract Yochem, J., Gu, T. and Han, M. 1998. A new marker for mosaic analysis in Caenorhabditis elegans indicates a fusion between hyp 6 and hyp7, two major components of the hypodermis. Genetics 149: 1323-1334. Article Yochem, J., Tuck, S., Greenwald, I. and Han, M. 1999. A gp330/megalin-related protein is required in the major epidermis of Caenorhabditis elegans for completion of molting. Development 126: 597-606. Article
This chapter should be cited as: Altun, Z.F. and Hall, D.H. 2009. Epithelial system, hypodermis. In WormAtlas. doi:10.3908/wormatlas.1.13 Edited for the web by Laura A. Herndon. Last revision: Dec 28, 2014.

©Copyright 2025 WormAtlas (Cold Spring Harbor Laboratory Press) All Rights Reserved |